import 'dart:typed_data';

import 'package:flutter_test/flutter_test.dart';

import 'package:crypto/crypto.dart';
import 'package:cryptor/pbkdf2.dart';

void main() {
  List<int> key;
  final PBKDF2 generator = new PBKDF2(sha512);
  final String password = 'password';
  final Uint8List salt = Uint8List.fromList([
    49,
    3,
    239,
    154,
    144,
    119,
    1,
    179,
    39,
    95,
    202,
    162,
    85,
    242,
    222,
    240,
    197,
    203,
    194,
    141,
    242,
    46,
    34,
    180,
    165,
    241,
    242,
    163,
    227,
    141,
    183,
    247,
    76,
    85,
    18,
    139,
    255,
    190,
    142,
    241,
    178,
    4,
    183,
    204,
    58,
    7,
    161,
    84,
    251,
    181,
    210,
    218,
    36,
    65,
    207,
    112,
    38,
    251,
    11,
    72,
    196,
    30,
    3,
    143
  ]);

  test('Derives 16 bit key from password and salt', () {
    key = generator.generateKey(password, salt, 100000, 16);
    expect(key, [
      38,
      11,
      27,
      194,
      233,
      120,
      192,
      88,
      137,
      233,
      67,
      73,
      165,
      92,
      41,
      112
    ]);
  });

  test('Derives 32 bit key from password and salt', () {
    key = generator.generateKey(password, salt, 100000, 32);
    expect(key, [
      38,
      11,
      27,
      194,
      233,
      120,
      192,
      88,
      137,
      233,
      67,
      73,
      165,
      92,
      41,
      112,
      168,
      252,
      140,
      24,
      239,
      79,
      222,
      27,
      33,
      10,
      158,
      88,
      77,
      11,
      144,
      208
    ]);
  });

  test('Derives 64 bit key from password and salt', () {
    key = generator.generateKey(password, salt, 100000, 64);
    expect(key, [
      38,
      11,
      27,
      194,
      233,
      120,
      192,
      88,
      137,
      233,
      67,
      73,
      165,
      92,
      41,
      112,
      168,
      252,
      140,
      24,
      239,
      79,
      222,
      27,
      33,
      10,
      158,
      88,
      77,
      11,
      144,
      208,
      46,
      105,
      9,
      4,
      127,
      52,
      139,
      201,
      126,
      76,
      17,
      199,
      45,
      182,
      68,
      23,
      78,
      17,
      85,
      235,
      240,
      34,
      167,
      254,
      248,
      101,
      106,
      23,
      144,
      249,
      203,
      175
    ]);
  });
}
